@@ -34,21 +34,6 @@ from supybot.test import *
 class GoogleTestCase(ChannelPluginTestCase):
     plugins = ('Google', 'Config')
     if network:
-        def testCalcHandlesMultiplicationSymbol(self):
-            self.assertNotRegexp('google calc seconds in a century', r'215')
-
-        def testCalc(self):
-            self.assertNotRegexp('google calc e^(i*pi)+1', r'didn\'t')
-            self.assertNotRegexp('google calc 1 usd in gbp', r'didn\'t')
-
-        def testHtmlHandled(self):
-            self.assertNotRegexp('google calc '
-                                 'the speed of light '
-                                 'in microns / fortnight', '<sup>')
-            self.assertNotRegexp('google calc '
-                                 'the speed of light '
-                                 'in microns / fortnight', '&times;')
-
         def testSearch(self):
             self.assertNotError('google foo')
             self.assertRegexp('google dupa', r'dupa')
@@ -76,14 +61,7 @@ class GoogleTestCase(ChannelPluginTestCase):
             self.assertNotError('config plugins.Google.oneToOne True')
             self.assertNotRegexp('google dupa', ';')
 
-        def testFight(self):
-            self.assertRegexp('fight supybot moobot', r'.*supybot.*: \d+')
-            self.assertNotError('fight ... !')
-
         def testTranslate(self):
             self.assertRegexp('translate en es hello world', 'Hola mundo')
 
-        def testCalcDoesNotHaveExtraSpaces(self):
-            self.assertNotRegexp('google calc 1000^2', r'\s+,\s+')
-
 # vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
