@@ -227,6 +227,10 @@ repositories = utils.InsensitivePreservingDict({
                                                    'oddluck',
                                                    'limnoria-plugins',
                                                    ),
+               'appas':            GithubRepository(
+                                                   'matiasw',
+                                                   'my-limnoria-plugins',
+                                                   ),
                })
 
 class PluginDownloader(callbacks.Plugin):
