@@ -941,7 +941,7 @@ class Directory(registry.String):
         if os.path.isabs(filename):
             filename = os.path.abspath(filename)
             selfAbs = os.path.abspath(myself)
-            commonPrefix = os.path.commonprefix([selfAbs, filename])
+            commonPrefix = os.path.commonpath([selfAbs, filename])
             filename = filename[len(commonPrefix):]
         elif not os.path.isabs(myself):
             if filename.startswith(myself):
@@ -954,7 +954,7 @@ class DataFilename(registry.String):
     def __call__(self):
         v = super(DataFilename, self).__call__()
         dataDir = supybot.directories.data()
-        if not v.startswith(dataDir):
+        if not v.startswith("/") and not v.startswith(dataDir):
             v = os.path.basename(v)
             v = os.path.join(dataDir, v)
         self.setValue(v)
