@@ -1494,26 +1494,41 @@ class BatchTestCase(SupyTestCase):
 
 class SaslTestCase(SupyTestCase, CapNegMixin):
     def setUp(self):
-        pass
+        self._default_mechanisms = conf.supybot.networks.test.sasl.mechanisms()
+
+    def tearDown(self):
+        conf.supybot.networks.test.sasl.mechanisms.setValue(self._default_mechanisms)
+        conf.supybot.networks.test.sasl.username.setValue('')
+        conf.supybot.networks.test.sasl.password.setValue('')
+        conf.supybot.networks.test.certfile.setValue('')
 
     def testPlain(self):
-        try:
-            conf.supybot.networks.test.sasl.username.setValue('jilles')
-            conf.supybot.networks.test.sasl.password.setValue('sesame')
-            self.irc = irclib.Irc('test')
-        finally:
-            conf.supybot.networks.test.sasl.username.setValue('')
-            conf.supybot.networks.test.sasl.password.setValue('')
+        conf.supybot.networks.test.sasl.username.setValue('jilles')
+        conf.supybot.networks.test.sasl.password.setValue('sesame')
+        conf.supybot.networks.test.sasl.mechanisms.setValue(
+            ['scram-sha-256', 'plain'])
+
+        self.irc = irclib.Irc('test')
+
         self.assertEqual(self.irc.sasl_current_mechanism, None)
-        self.irc.sasl_next_mechanisms = ['scram-sha-256', 'plain']
 
-        self.startCapNegociation()
+        if irclib.scram:
+            self.assertEqual(self.irc.sasl_next_mechanisms,
+                ['scram-sha-256', 'plain'])
+
+            self.startCapNegociation()
+
+            m = self.irc.takeMsg()
+            self.assertEqual(m, ircmsgs.IrcMsg(command='AUTHENTICATE',
+                args=('SCRAM-SHA-256',)))
+            self.irc.feedMsg(ircmsgs.IrcMsg(command='904',
+                args=('mechanism not available',)))
+        else:
+            self.assertEqual(self.irc.sasl_next_mechanisms,
+                ['plain'])
+
+            self.startCapNegociation()
 
-        m = self.irc.takeMsg()
-        self.assertEqual(m, ircmsgs.IrcMsg(command='AUTHENTICATE',
-            args=('SCRAM-SHA-256',)))
-        self.irc.feedMsg(ircmsgs.IrcMsg(command='904',
-            args=('mechanism not available',)))
 
         m = self.irc.takeMsg()
         self.assertEqual(m, ircmsgs.IrcMsg(command='AUTHENTICATE',
@@ -1531,17 +1546,17 @@ class SaslTestCase(SupyTestCase, CapNegMixin):
         self.endCapNegociation()
 
     def testExternalFallbackToPlain(self):
-        try:
-            conf.supybot.networks.test.sasl.username.setValue('jilles')
-            conf.supybot.networks.test.sasl.password.setValue('sesame')
-            conf.supybot.networks.test.certfile.setValue('foo')
-            self.irc = irclib.Irc('test')
-        finally:
-            conf.supybot.networks.test.sasl.username.setValue('')
-            conf.supybot.networks.test.sasl.password.setValue('')
-            conf.supybot.networks.test.certfile.setValue('')
+        conf.supybot.networks.test.sasl.username.setValue('jilles')
+        conf.supybot.networks.test.sasl.password.setValue('sesame')
+        conf.supybot.networks.test.certfile.setValue('foo')
+        conf.supybot.networks.test.sasl.mechanisms.setValue(
+            ['external', 'plain'])
+
+        self.irc = irclib.Irc('test')
+
         self.assertEqual(self.irc.sasl_current_mechanism, None)
-        self.irc.sasl_next_mechanisms = ['external', 'plain']
+        self.assertEqual(self.irc.sasl_next_mechanisms,
+            ['external', 'plain'])
 
         self.startCapNegociation()
 
@@ -1567,17 +1582,17 @@ class SaslTestCase(SupyTestCase, CapNegMixin):
         self.endCapNegociation()
 
     def testFilter(self):
-        try:
-            conf.supybot.networks.test.sasl.username.setValue('jilles')
-            conf.supybot.networks.test.sasl.password.setValue('sesame')
-            conf.supybot.networks.test.certfile.setValue('foo')
-            self.irc = irclib.Irc('test')
-        finally:
-            conf.supybot.networks.test.sasl.username.setValue('')
-            conf.supybot.networks.test.sasl.password.setValue('')
-            conf.supybot.networks.test.certfile.setValue('')
+        conf.supybot.networks.test.sasl.username.setValue('jilles')
+        conf.supybot.networks.test.sasl.password.setValue('sesame')
+        conf.supybot.networks.test.certfile.setValue('foo')
+        conf.supybot.networks.test.sasl.mechanisms.setValue(
+            ['external', 'plain'])
+
+        self.irc = irclib.Irc('test')
+
         self.assertEqual(self.irc.sasl_current_mechanism, None)
-        self.irc.sasl_next_mechanisms = ['external', 'plain']
+        self.assertEqual(self.irc.sasl_next_mechanisms,
+            ['external', 'plain'])
 
         self.startCapNegociation(caps='sasl=foo,plain,bar')
 
@@ -1597,15 +1612,16 @@ class SaslTestCase(SupyTestCase, CapNegMixin):
         self.endCapNegociation()
 
     def testReauthenticate(self):
-        try:
-            conf.supybot.networks.test.sasl.username.setValue('jilles')
-            conf.supybot.networks.test.sasl.password.setValue('sesame')
-            self.irc = irclib.Irc('test')
-        finally:
-            conf.supybot.networks.test.sasl.username.setValue('')
-            conf.supybot.networks.test.sasl.password.setValue('')
+        conf.supybot.networks.test.sasl.username.setValue('jilles')
+        conf.supybot.networks.test.sasl.password.setValue('sesame')
+        conf.supybot.networks.test.sasl.mechanisms.setValue(
+            ['external', 'plain'])
+
+        self.irc = irclib.Irc('test')
+
         self.assertEqual(self.irc.sasl_current_mechanism, None)
-        self.irc.sasl_next_mechanisms = ['plain']
+        self.assertEqual(self.irc.sasl_next_mechanisms,
+            ['plain'])
 
         self.startCapNegociation(caps='')
 
@@ -1622,16 +1638,12 @@ class SaslTestCase(SupyTestCase, CapNegMixin):
         self.irc.takeMsg() # None. But even if it was CAP REQ sasl, it would be ok
         self.assertEqual(self.irc.takeMsg(), None)
 
-        try:
-            conf.supybot.networks.test.sasl.username.setValue('jilles')
-            conf.supybot.networks.test.sasl.password.setValue('sesame')
-            self.irc.feedMsg(ircmsgs.IrcMsg(command='CAP',
-                    args=('*', 'DEL', 'sasl')))
-            self.irc.feedMsg(ircmsgs.IrcMsg(command='CAP',
-                    args=('*', 'NEW', 'sasl=PLAIN')))
-        finally:
-            conf.supybot.networks.test.sasl.username.setValue('')
-            conf.supybot.networks.test.sasl.password.setValue('')
+        conf.supybot.networks.test.sasl.username.setValue('jilles')
+        conf.supybot.networks.test.sasl.password.setValue('sesame')
+        self.irc.feedMsg(ircmsgs.IrcMsg(command='CAP',
+                args=('*', 'DEL', 'sasl')))
+        self.irc.feedMsg(ircmsgs.IrcMsg(command='CAP',
+                args=('*', 'NEW', 'sasl=PLAIN')))
 
         m = self.irc.takeMsg()
         self.assertEqual(m.command, 'CAP', 'Expected CAP, got %r.' % m)
